/* ser_serial.h
 * 
 * Provides cross-platform access to the serial port.
 * 
 * Copyright (C) 2000, Winford Engineering.
 * See file LICENSE.txt for details.
 * 
 * Winford Engineering
 * www.winfordeng.com
 */

/* 
 * These functions are specialized for this particular
 * library, and are not meant to be general purpose.
 * These functions will NOT be used directly by the user.
 * 
 * MUST have either LINUX or WIN95 or WINNT #defined.
 */

#ifndef ser_serial_h
#define ser_serial_h

#ifndef COMMONWIN 
#ifdef WIN95
#define COMMONWIN
#endif
#ifdef WINNT
#define COMMONWIN
#endif
#endif

#include "ser_error.h"

#ifdef COMMONWIN
#include <windows.h>
typedef struct
{
	HANDLE fd;
	DCB oldattr;
	DCB newattr;
	OVERLAPPED overwrite; /* for writing data */
	OVERLAPPED overread;  /* for reading data */
	unsigned int timeout; /* timeout in milliseconds */
} ser_serial;
#endif

#ifdef LINUX
#include <unistd.h>
#include <termios.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/stat.h>

typedef struct
{
	int fd;
	struct termios newattr;
	struct termios oldattr;	
} ser_serial;
#endif

/* SER_SERIAL_TIMEOUT is the default length of time in milliseconds 
 * that a read operation will time out from inactivity.
 */
#define SER_SERIAL_TIMEOUT 1500


#define SER_1200   9
#define SER_2400  11
#define SER_4800  12
#define SER_9600  13
#define SER_19200 14
#define SER_38400 15

int ser_serial_open(ser_serial *serial, char *path, unsigned int baud);
int ser_serial_timeout(ser_serial *serial, unsigned int timeout);
int ser_serial_write(ser_serial *serial, char *data, int length);
int ser_serial_readline(ser_serial *serial, char *data, int length, int *actual);
int ser_serial_close(ser_serial *serial);

#endif // ser_serial_h